BottomSheetStyles class

BottomSheetStyles : Configuration for customizing the bottom sheet's appearance and behavior.

  • backgroundColor: The background color of the bottom sheet. Default = Colors.white.
  • shape: The shape of the bottom sheet. It can be used to set a custom shape like a rounded corner.
  • elevation: The elevation (shadow) of the bottom sheet. Default = 4.0.
  • galleryButton: Configuration for the gallery button displayed inside the bottom sheet.
  • cameraButton: Configuration for the camera button displayed inside the bottom sheet.
  • middleText: Text displayed between the camera and gallery buttons. Default = "OR".
  • middleTextStyle: The text style for the middle text. Default = TextStyle().

Constructors

BottomSheetStyles({required Color? backgroundColor, ShapeBorder? shape, GalleryBottom? galleryButton, CameraButton? cameraButton, required double? elevation, required String? middleText, required TextStyle? middleTextStyle})

Properties

backgroundColor Color?
getter/setter pair
cameraButton CameraButton?
final
elevation double?
getter/setter pair
galleryButton GalleryBottom?
final
hashCode int
The hash code for this object.
no setterinherited
middleText String?
getter/setter pair
middleTextStyle TextStyle?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape ShapeBorder?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited