CameraButton class
CameraButton : Configuration for the camera button in the bottom sheet.
- text: The text label displayed on the camera button. Default = "Use camera".
- style: The text style for the button label.
Default =
TextStyle(). - color: The background color of the camera button.
Default =
Colors.grey.shade100. - icon: The icon displayed next to the text on the camera button.
Default =
Icons.camera_alt_outlined.
Constructors
- CameraButton({required TextStyle? style, required Color color, required String text, required Icon? icon})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited