GalleryBottom class

GalleryBottom : Configuration for the gallery button in the bottom sheet.

  • text: The text label displayed on the gallery button. Default = "Browse Gallery".
  • style: The text style for the button label. Default = TextStyle().
  • color: The background color of the gallery button. Default = Colors.grey.shade100.
  • icon: The icon displayed next to the text on the gallery button. Default = Icons.image_outlined.

Constructors

GalleryBottom({required TextStyle? style, required Color color, required String text, required Icon? icon})

Properties

color Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icon Icon?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
getter/setter pair
text String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited