StatusIndicatorSettings class

Constructors

StatusIndicatorSettings({bool isOnline = false, StatusIndicatorStyle style = StatusIndicatorStyle.dot, Color onlineColor = Colors.green, Color offlineColor = Colors.grey, double size = 12.0, EdgeInsets padding = const EdgeInsets.all(2.0), bool showBorder = true, Color borderColor = Colors.white, double borderWidth = 2.0, bool showShadow = true, Color shadowColor = Colors.black, Offset shadowOffset = const Offset(0, 2), double shadowBlurRadius = 4.0, StatusIndicatorAlignment alignment = StatusIndicatorAlignment.bottomRight})
const

Properties

alignment StatusIndicatorAlignment
final
border Border?
no setter
borderColor Color
final
borderWidth double
final
currentColor Color
no setter
hashCode int
The hash code for this object.
no setterinherited
isOnline bool
final
offlineColor Color
final
onlineColor Color
final
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadow List<BoxShadow>?
no setter
shadowBlurRadius double
final
shadowColor Color
final
shadowOffset Offset
final
showBorder bool
final
showShadow bool
final
size double
final
style StatusIndicatorStyle
final

Methods

copyWith({bool? isOnline, StatusIndicatorStyle? style, Color? onlineColor, Color? offlineColor, double? size, EdgeInsets? padding, bool? showBorder, Color? borderColor, double? borderWidth, bool? showShadow, Color? shadowColor, Offset? shadowOffset, double? shadowBlurRadius, StatusIndicatorAlignment? alignment}) StatusIndicatorSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited