avatar_better_pro library
Classes
- Avatar
- A widget that displays an avatar image.
- BottomSheetStyles
- BottomSheetStyles : Configuration for customizing the bottom sheet's appearance and behavior.
- CameraButton
- CameraButton : Configuration for the camera button in the bottom sheet.
- GalleryBottom
- GalleryBottom : Configuration for the gallery button in the bottom sheet.
- StatusIndicatorSettings
Extensions
Typedefs
- OnPickerChange = void Function(File file, Uint8List bytes)